# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFFTPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkFFTWGlobalConfigurationPython
else:
    import _itkFFTWGlobalConfigurationPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrix_fixedPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
class itkFFTWGlobalConfiguration(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkFFTWGlobalConfiguration class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def GetLockMutex():
        r"""GetLockMutex() -> std::mutex &"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetLockMutex()

    @staticmethod
    def SetNewWisdomAvailable(v):
        r"""
        SetNewWisdomAvailable(v)

        Parameters
        ----------
        v: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_SetNewWisdomAvailable(v)

    @staticmethod
    def GetNewWisdomAvailable():
        r"""GetNewWisdomAvailable() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetNewWisdomAvailable()

    @staticmethod
    def GetPlanRigor():
        r"""GetPlanRigor() -> int"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetPlanRigor()

    @staticmethod
    def SetPlanRigor(*args):
        r"""
        SetPlanRigor(v)

        Parameters
        ----------
        v: int const

        SetPlanRigor(name)

        Parameters
        ----------
        name: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_SetPlanRigor(*args)

    @staticmethod
    def GetPlanRigorValue(name):
        r"""
        GetPlanRigorValue(name) -> int

        Parameters
        ----------
        name: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetPlanRigorValue(name)

    @staticmethod
    def GetPlanRigorName(value):
        r"""
        GetPlanRigorName(value) -> std::string

        Parameters
        ----------
        value: int const

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetPlanRigorName(value)

    @staticmethod
    def SetReadWisdomCache(v):
        r"""
        SetReadWisdomCache(v)

        Parameters
        ----------
        v: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_SetReadWisdomCache(v)

    @staticmethod
    def GetReadWisdomCache():
        r"""GetReadWisdomCache() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetReadWisdomCache()

    @staticmethod
    def SetWriteWisdomCache(v):
        r"""
        SetWriteWisdomCache(v)

        Parameters
        ----------
        v: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_SetWriteWisdomCache(v)

    @staticmethod
    def GetWriteWisdomCache():
        r"""GetWriteWisdomCache() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetWriteWisdomCache()

    @staticmethod
    def SetWisdomCacheBase(v):
        r"""
        SetWisdomCacheBase(v)

        Parameters
        ----------
        v: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_SetWisdomCacheBase(v)

    @staticmethod
    def GetWisdomCacheBase():
        r"""GetWisdomCacheBase() -> std::string"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetWisdomCacheBase()

    @staticmethod
    def SetWisdomFilenameGenerator(wfg):
        r"""
        SetWisdomFilenameGenerator(wfg)

        Parameters
        ----------
        wfg: itkWisdomFilenameGeneratorBase *

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_SetWisdomFilenameGenerator(wfg)

    @staticmethod
    def GetWisdomFileDefaultBaseName():
        r"""GetWisdomFileDefaultBaseName() -> std::string"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_GetWisdomFileDefaultBaseName()

    @staticmethod
    def ImportWisdomFileDouble(fname):
        r"""
        ImportWisdomFileDouble(fname) -> bool

        Parameters
        ----------
        fname: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ImportWisdomFileDouble(fname)

    @staticmethod
    def ExportWisdomFileDouble(fname):
        r"""
        ExportWisdomFileDouble(fname) -> bool

        Parameters
        ----------
        fname: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ExportWisdomFileDouble(fname)

    @staticmethod
    def ImportWisdomFileFloat(fname):
        r"""
        ImportWisdomFileFloat(fname) -> bool

        Parameters
        ----------
        fname: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ImportWisdomFileFloat(fname)

    @staticmethod
    def ExportWisdomFileFloat(fname):
        r"""
        ExportWisdomFileFloat(fname) -> bool

        Parameters
        ----------
        fname: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ExportWisdomFileFloat(fname)

    @staticmethod
    def ImportDefaultWisdomFileDouble():
        r"""ImportDefaultWisdomFileDouble() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ImportDefaultWisdomFileDouble()

    @staticmethod
    def ExportDefaultWisdomFileDouble():
        r"""ExportDefaultWisdomFileDouble() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ExportDefaultWisdomFileDouble()

    @staticmethod
    def ImportDefaultWisdomFileFloat():
        r"""ImportDefaultWisdomFileFloat() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ImportDefaultWisdomFileFloat()

    @staticmethod
    def ExportDefaultWisdomFileFloat():
        r"""ExportDefaultWisdomFileFloat() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ExportDefaultWisdomFileFloat()

    @staticmethod
    def ImportDefaultWisdomFile():
        r"""ImportDefaultWisdomFile() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ImportDefaultWisdomFile()

    @staticmethod
    def ExportDefaultWisdomFile():
        r"""ExportDefaultWisdomFile() -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_ExportDefaultWisdomFile()

# Register itkFFTWGlobalConfiguration in _itkFFTWGlobalConfigurationPython:
_itkFFTWGlobalConfigurationPython.itkFFTWGlobalConfiguration_swigregister(itkFFTWGlobalConfiguration)
class itkWisdomFilenameGeneratorBase(object):
    r"""Proxy of C++ itkWisdomFilenameGeneratorBase class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GenerateWisdomFilename(self, baseCacheDirectory):
        r"""
        GenerateWisdomFilename(self, baseCacheDirectory) -> std::string

        Parameters
        ----------
        baseCacheDirectory: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkWisdomFilenameGeneratorBase_GenerateWisdomFilename(self, baseCacheDirectory)
    __swig_destroy__ = _itkFFTWGlobalConfigurationPython.delete_itkWisdomFilenameGeneratorBase

# Register itkWisdomFilenameGeneratorBase in _itkFFTWGlobalConfigurationPython:
_itkFFTWGlobalConfigurationPython.itkWisdomFilenameGeneratorBase_swigregister(itkWisdomFilenameGeneratorBase)
class itkHardwareWisdomFilenameGenerator(itkWisdomFilenameGeneratorBase):
    r"""Proxy of C++ itkHardwareWisdomFilenameGenerator class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def SetUseOSName(self, flag):
        r"""
        SetUseOSName(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseOSName(self, flag)

    def SetUseOSRelease(self, flag):
        r"""
        SetUseOSRelease(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseOSRelease(self, flag)

    def SetUseOSVersion(self, flag):
        r"""
        SetUseOSVersion(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseOSVersion(self, flag)

    def SetUseOSPlatform(self, flag):
        r"""
        SetUseOSPlatform(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseOSPlatform(self, flag)

    def SetUseOSBitSize(self, flag):
        r"""
        SetUseOSBitSize(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseOSBitSize(self, flag)

    def SetUseNumberOfProcessors(self, flag):
        r"""
        SetUseNumberOfProcessors(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseNumberOfProcessors(self, flag)

    def SetUseVendorString(self, flag):
        r"""
        SetUseVendorString(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseVendorString(self, flag)

    def SetUseTypeID(self, flag):
        r"""
        SetUseTypeID(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseTypeID(self, flag)

    def SetUseFamilyID(self, flag):
        r"""
        SetUseFamilyID(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseFamilyID(self, flag)

    def SetUseModelID(self, flag):
        r"""
        SetUseModelID(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseModelID(self, flag)

    def SetUseSteppingCode(self, flag):
        r"""
        SetUseSteppingCode(self, flag)

        Parameters
        ----------
        flag: bool const

        """
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_SetUseSteppingCode(self, flag)

    def GetUseOSName(self):
        r"""GetUseOSName(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseOSName(self)

    def GetUseOSRelease(self):
        r"""GetUseOSRelease(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseOSRelease(self)

    def GetUseOSVersion(self):
        r"""GetUseOSVersion(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseOSVersion(self)

    def GetUseOSPlatform(self):
        r"""GetUseOSPlatform(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseOSPlatform(self)

    def GetUseOSBitSize(self):
        r"""GetUseOSBitSize(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseOSBitSize(self)

    def GetUseNumberOfProcessors(self):
        r"""GetUseNumberOfProcessors(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseNumberOfProcessors(self)

    def GetUseVendorString(self):
        r"""GetUseVendorString(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseVendorString(self)

    def GetUseTypeID(self):
        r"""GetUseTypeID(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseTypeID(self)

    def GetUseFamilyID(self):
        r"""GetUseFamilyID(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseFamilyID(self)

    def GetUseModelID(self):
        r"""GetUseModelID(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseModelID(self)

    def GetUseSteppingCode(self):
        r"""GetUseSteppingCode(self) -> bool"""
        return _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_GetUseSteppingCode(self)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkHardwareWisdomFilenameGenerator
        __init__(self, arg0) -> itkHardwareWisdomFilenameGenerator

        Parameters
        ----------
        arg0: itkHardwareWisdomFilenameGenerator const &

        """
        _itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_swiginit(self, _itkFFTWGlobalConfigurationPython.new_itkHardwareWisdomFilenameGenerator(*args))
    __swig_destroy__ = _itkFFTWGlobalConfigurationPython.delete_itkHardwareWisdomFilenameGenerator

# Register itkHardwareWisdomFilenameGenerator in _itkFFTWGlobalConfigurationPython:
_itkFFTWGlobalConfigurationPython.itkHardwareWisdomFilenameGenerator_swigregister(itkHardwareWisdomFilenameGenerator)
class itkHostnameWisdomFilenameGenerator(itkWisdomFilenameGeneratorBase):
    r"""Proxy of C++ itkHostnameWisdomFilenameGenerator class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _itkFFTWGlobalConfigurationPython.delete_itkHostnameWisdomFilenameGenerator

    def __init__(self, *args):
        r"""
        __init__(self, arg0) -> itkHostnameWisdomFilenameGenerator

        Parameters
        ----------
        arg0: itkHostnameWisdomFilenameGenerator const &

        __init__(self) -> itkHostnameWisdomFilenameGenerator
        """
        _itkFFTWGlobalConfigurationPython.itkHostnameWisdomFilenameGenerator_swiginit(self, _itkFFTWGlobalConfigurationPython.new_itkHostnameWisdomFilenameGenerator(*args))

# Register itkHostnameWisdomFilenameGenerator in _itkFFTWGlobalConfigurationPython:
_itkFFTWGlobalConfigurationPython.itkHostnameWisdomFilenameGenerator_swigregister(itkHostnameWisdomFilenameGenerator)
class itkManualWisdomFilenameGenerator(itkWisdomFilenameGeneratorBase):
    r"""Proxy of C++ itkManualWisdomFilenameGenerator class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def SetWisdomFilename(self, wfn):
        r"""
        SetWisdomFilename(self, wfn)

        Parameters
        ----------
        wfn: std::string const &

        """
        return _itkFFTWGlobalConfigurationPython.itkManualWisdomFilenameGenerator_SetWisdomFilename(self, wfn)

    def __init__(self, *args):
        r"""
        __init__(self, wfn) -> itkManualWisdomFilenameGenerator

        Parameters
        ----------
        wfn: std::string

        __init__(self, arg0) -> itkManualWisdomFilenameGenerator

        Parameters
        ----------
        arg0: itkManualWisdomFilenameGenerator const &

        """
        _itkFFTWGlobalConfigurationPython.itkManualWisdomFilenameGenerator_swiginit(self, _itkFFTWGlobalConfigurationPython.new_itkManualWisdomFilenameGenerator(*args))
    __swig_destroy__ = _itkFFTWGlobalConfigurationPython.delete_itkManualWisdomFilenameGenerator

# Register itkManualWisdomFilenameGenerator in _itkFFTWGlobalConfigurationPython:
_itkFFTWGlobalConfigurationPython.itkManualWisdomFilenameGenerator_swigregister(itkManualWisdomFilenameGenerator)
class itkSimpleWisdomFilenameGenerator(itkWisdomFilenameGeneratorBase):
    r"""Proxy of C++ itkSimpleWisdomFilenameGenerator class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _itkFFTWGlobalConfigurationPython.delete_itkSimpleWisdomFilenameGenerator

    def __init__(self, *args):
        r"""
        __init__(self, arg0) -> itkSimpleWisdomFilenameGenerator

        Parameters
        ----------
        arg0: itkSimpleWisdomFilenameGenerator const &

        __init__(self) -> itkSimpleWisdomFilenameGenerator
        """
        _itkFFTWGlobalConfigurationPython.itkSimpleWisdomFilenameGenerator_swiginit(self, _itkFFTWGlobalConfigurationPython.new_itkSimpleWisdomFilenameGenerator(*args))

# Register itkSimpleWisdomFilenameGenerator in _itkFFTWGlobalConfigurationPython:
_itkFFTWGlobalConfigurationPython.itkSimpleWisdomFilenameGenerator_swigregister(itkSimpleWisdomFilenameGenerator)

